Deserializer

Struct Deserializer 

pub(crate) struct Deserializer<'de> {
    buf: &'de [u8],
    pos: usize,
    rec: usize,
    seq: usize,
}
Deserialization state.

Fields

buf: &'de [u8]pos: usizerec: usizeseq: usize

Implementations

Source

impl<'de> Deserializer<'de>

const SEP: u8 = crate::ser::SEP

fn finished(&self) -> Result

Determine if the input was fully consumed and error if bytes remaining. This is intended for debug assertions; not optimized for parsing logic.

fn sequence_start(&mut self, len: usize)

Called at the start of arrays and tuples

fn record_ignore(&mut self)

Consume the current record to ignore it. Inside a sequence the next record is skipped but at the top-level all records are skipped such that deserialization completes with self.finished() == Ok.

fn record_ignore_all(&mut self)

Consume the current and all remaining records to ignore them. Similar to Ignore at the top-level, but it can be provided in a sequence to Ignore all remaining elements.

fn record_next(&mut self) -> &'de [u8]

Consume the current record. The position pointer is moved to the start of the next record. Slice of the current record is returned.

fn record_peek_byte(&self) -> Option<u8>

Peek at the first byte of the current record. If all records were consumed None is returned instead.

fn record_start(&mut self)

Consume the record separator such that the position cleanly points to the start of the next record. When input is exhausted but the sequence is not, advance no bytes; the caller deserializes from an empty slice. See next_element_seed for the additive-tail mechanic this enables.

fn record_trail(&mut self) -> &'de [u8]

Consume all remaining bytes, which may include record separators, returning a raw slice.

fn inc_pos(&mut self, n: usize)

Increment the position pointer.

fn inc_rec(&mut self, n: usize)

fn remaining(&self) -> Result<usize>

Unconsumed input bytes.