cf_options

Function cf_options 

pub(crate) fn cf_options(
    ctx: &Context,
    opts: Options,
    desc: &Descriptor,
) -> Result<Options>
Adjust options for the specific column by name. Provide the result of db_options() as the argument to this function and use the return value in the arguments to open the specific column.