Context

Struct Context 

pub(crate) struct Context {
    pub(crate) pool: Arc<Pool>,
    pub(crate) col_cache: Mutex<BTreeMap<&'static str, ColCache>>,
    pub(crate) row_cache: Mutex<Cache>,
    pub(crate) row_cache_capacity: usize,
    pub(crate) env: Mutex<Env>,
    pub(crate) server: Arc<Server>,
}
Some components are constructed prior to opening the database and must outlive the database. These can also be shared between database instances though at the time of this comment we only open one database per process. These assets are housed in the shared Context.

Fields

pool: Arc<Pool>col_cache: Mutex<BTreeMap<&'static str, ColCache>>row_cache: Mutex<Cache>row_cache_capacity: usize

Retained because rust-rocksdb’s Cache binding lacks get_capacity; needed for the admin renderer’s row-cache util%.

env: Mutex<Env>server: Arc<Server>

Implementations

Source

impl Context

pub(crate) fn new(server: &Arc<Server>) -> Result<Arc<Self>>