db_options

Function db_options 

pub(crate) fn db_options(
    config: &Config,
    env: &Env,
    row_cache: &Cache,
) -> Result<Options>
Create database-wide options suitable for opening the database. This also sets our default column options in case of opening a column with the same resulting value. Note that we require special per-column options on some columns, therefor columns should only be opened after passing this result through cf_options().