key

Function key 

pub fn key<K, V>(kv: KeyVal<'_, K, V>) -> Key<'_, K>
Returns the key component of a database pair.

The pair is consumed and its value component is dropped. No serialization or allocation is performed by this projection.