val

Function val 

pub fn val<K, V>(kv: KeyVal<'_, K, V>) -> Val<'_, V>
Returns the value component of a database pair.

The pair is consumed and its key component is dropped. No serialization or allocation is performed by this projection.