init

Function init 

fn init<'a>(state: State<'a>, dir: Direction, from: Option<&[u8]>) -> State<'a>
Initializes iterator state for the requested seek direction.

The optional raw key is interpreted as a lower bound when moving forward and an upper bound when moving backward.