pub struct Map {
name: &'static str,
watch: Watch,
cf: Arc<ColumnFamily>,
engine: Arc<Engine>,
read_options: ReadOptions,
cache_read_options: ReadOptions,
write_options: WriteOptions,
}Fields
name: &'static strwatch: Watchcf: Arc<ColumnFamily>engine: Arc<Engine>read_options: ReadOptionscache_read_options: ReadOptionswrite_options: WriteOptionsImplementations
Sourceimpl Map
impl Map
Sourcepub fn for_clear(self: &Arc<Self>) -> impl Stream<Item = Result<Key<'_>>> + Send
pub fn for_clear(self: &Arc<Self>) -> impl Stream<Item = Result<Key<'_>>> + Send
Delete all data stored in this map. !!! USE WITH CAUTION !!!
Provides stream of keys undergoing deletion along with any errors.
Note this operation applies to a snapshot of the data when invoked. Additional data written during or after this call may be missed.
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourcepub fn aqry<const MAX: usize, K>(
self: &Arc<Self>,
key: &K,
) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, MAX, K>
pub fn aqry<const MAX: usize, K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, MAX, K>
Fetch a value from the database into cache, returning a reference-handle asynchronously. The key is serialized into a fixed-sized buffer to perform the query. The maximum size is supplied as const generic parameter.
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourcepub fn rev_stream_raw_prefix<'a, K, V, P>(
self: &'a Arc<Self>,
prefix: &'a P,
) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'awhere
P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,
K: Deserialize<'a> + Send + 'a,
V: Deserialize<'a> + Send + 'a,
pub fn rev_stream_raw_prefix<'a, K, V, P>(
self: &'a Arc<Self>,
prefix: &'a P,
) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'awhere
P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,
K: Deserialize<'a> + Send + 'a,
V: Deserialize<'a> + Send + 'a,
Iterate key-value entries in the map where the key matches a prefix.
- Query is raw
- Result is deserialized
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourceimpl Map
impl Map
Sourcepub fn stream_raw_prefix<'a, K, V, P>(
self: &'a Arc<Self>,
prefix: &'a P,
) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'awhere
P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,
K: Deserialize<'a> + Send + 'a,
V: Deserialize<'a> + Send + 'a,
pub fn stream_raw_prefix<'a, K, V, P>(
self: &'a Arc<Self>,
prefix: &'a P,
) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'awhere
P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,
K: Deserialize<'a> + Send + 'a,
V: Deserialize<'a> + Send + 'a,
Iterate key-value entries in the map where the key matches a prefix.
- Query is raw
- Result is deserialized
Sourceimpl Map
impl Map
pub(crate) fn open( engine: &Arc<Engine>, name: &'static str, ) -> Result<Arc<Self>>
pub fn property_integer(&self, name: &CStr) -> Result<u64>
pub fn property(&self, name: &str) -> Result<String>
pub fn name(&self) -> &str
pub(crate) fn engine(&self) -> &Arc<Engine> ⓘ
pub(crate) fn cf(&self) -> impl AsColumnFamilyRef + '_