fn take_varint32(data: &mut &Slice) -> Option<u32>Expand description
Takes one RocksDB varint32 from the front of a batch record.
The parser consumes at most five bytes and advances data as bytes are
read. A missing byte or a continuation bit on the fifth byte returns None.