pub(crate) struct Deserializer<'de> {
buf: &'de [u8],
pos: usize,
rec: usize,
seq: usize,
}Expand description
Deserialization state.
Fields
buf: &'de [u8]pos: usizerec: usizeseq: usizeImplementations
Sourceimpl<'de> Deserializer<'de>
impl<'de> Deserializer<'de>
const SEP: u8 = crate::ser::SEP
Sourcefn finished(&self) -> Result
fn finished(&self) -> Result
Determine if the input was fully consumed and error if bytes remaining. This is intended for debug assertions; not optimized for parsing logic.
Sourcefn sequence_start(&mut self, len: usize)
fn sequence_start(&mut self, len: usize)
Called at the start of arrays and tuples
Sourcefn record_ignore(&mut self)
fn record_ignore(&mut self)
Consume the current record to ignore it. Inside a sequence the next record is skipped but at the top-level all records are skipped such that deserialization completes with self.finished() == Ok.
Sourcefn record_ignore_all(&mut self)
fn record_ignore_all(&mut self)
Consume the current and all remaining records to ignore them. Similar to Ignore at the top-level, but it can be provided in a sequence to Ignore all remaining elements.
Sourcefn record_next(&mut self) -> &'de [u8] ⓘ
fn record_next(&mut self) -> &'de [u8] ⓘ
Consume the current record. The position pointer is moved to the start of the next record. Slice of the current record is returned.
Sourcefn record_peek_byte(&self) -> Option<u8>
fn record_peek_byte(&self) -> Option<u8>
Peek at the first byte of the current record. If all records were consumed None is returned instead.
Sourcefn record_start(&mut self)
fn record_start(&mut self)
Consume the record separator such that the position cleanly points to
the start of the next record. When input is exhausted but the
sequence is not, advance no bytes; the caller deserializes from an
empty slice. See next_element_seed for the additive-tail mechanic
this enables.
Sourcefn record_trail(&mut self) -> &'de [u8] ⓘ
fn record_trail(&mut self) -> &'de [u8] ⓘ
Consume all remaining bytes, which may include record separators, returning a raw slice.
fn inc_rec(&mut self, n: usize)