Map

Struct Map 

pub struct Map {
    name: &'static str,
    watch: Watch,
    cf: Arc<ColumnFamily>,
    engine: Arc<Engine>,
    read_options: ReadOptions,
    cache_read_options: ReadOptions,
    write_options: WriteOptions,
}

Fields

name: &'static strwatch: Watchcf: Arc<ColumnFamily>engine: Arc<Engine>read_options: ReadOptionscache_read_options: ReadOptionswrite_options: WriteOptions

Implementations

Source

impl Map

pub async fn clear(self: &Arc<Self>)

Delete all data stored in this map. !!! USE WITH CAUTION !!!

See for_clear() with additional details.

Source

impl Map

pub fn for_clear(self: &Arc<Self>) -> impl Stream<Item = Result<Key<'_>>> + Send

Delete all data stored in this map. !!! USE WITH CAUTION !!!

Provides stream of keys undergoing deletion along with any errors.

Note this operation applies to a snapshot of the data when invoked. Additional data written during or after this call may be missed.

Source

impl Map

pub fn compact_blocking(&self, opts: Options) -> Result

Source

impl Map

pub fn contains<K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = bool> + Send + '_ + use<'_, K>
where K: Serialize + ?Sized + Debug,

Returns true if the map contains the key.

  • key is serialized into allocated buffer
  • harder errors may not be reported
Source

impl Map

pub fn acontains<const MAX: usize, K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = bool> + Send + '_ + use<'_, MAX, K>
where K: Serialize + ?Sized + Debug,

Returns true if the map contains the key.

  • key is serialized into stack-buffer
  • harder errors will panic
Source

impl Map

pub fn bcontains<K, B>( self: &Arc<Self>, key: &K, buf: &mut B, ) -> impl Future<Output = bool> + Send + '_ + use<'_, K, B>
where K: Serialize + ?Sized + Debug, B: Write + AsRef<[u8]>,

Returns true if the map contains the key.

  • key is serialized into provided buffer
  • harder errors will panic
Source

impl Map

pub fn exists<'a, K>( self: &'a Arc<Self>, key: &K, ) -> impl Future<Output = Result> + Send + 'a + use<'a, K>
where K: AsRef<[u8]> + ?Sized + Debug + 'a,

Returns Ok if the map contains the key.

  • key is raw
Source

impl Map

pub fn exists_blocking<K>(&self, key: &K) -> Result
where K: AsRef<[u8]> + ?Sized + Debug,

Returns Ok if the map contains the key; NotFound otherwise. Harder errors may not always be reported properly.

Source

impl Map

pub(crate) fn maybe_exists<K>(&self, key: &K) -> bool
where K: AsRef<[u8]> + ?Sized,

Rocksdb limits this to kBlockCacheTier internally so this is not actually a blocking call; in case that changes we set this as well in our read_options.

Source

impl Map

pub fn count(self: &Arc<Self>) -> impl Future<Output = usize> + Send + '_

Count the total number of entries in the map.

Source

impl Map

pub fn count_from<'a, P>( self: &'a Arc<Self>, from: &P, ) -> impl Future<Output = usize> + Send + 'a + use<'a, P>
where P: Serialize + ?Sized + Debug + 'a,

Count the number of entries in the map starting from a lower-bound.

  • From is a structured key
Source

impl Map

pub fn raw_count_from<'a, P>( self: &'a Arc<Self>, from: &'a P, ) -> impl Future<Output = usize> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Count the number of entries in the map starting from a lower-bound.

  • From is a raw
Source

impl Map

pub fn count_prefix<'a, P>( self: &'a Arc<Self>, prefix: &P, ) -> impl Future<Output = usize> + Send + 'a + use<'a, P>
where P: Serialize + ?Sized + Debug + 'a,

Count the number of entries in the map matching a prefix.

  • Prefix is structured key
Source

impl Map

pub fn raw_count_prefix<'a, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Future<Output = usize> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Count the number of entries in the map matching a prefix.

  • Prefix is raw
Source

impl Map

pub fn del<K>(&self, key: K)
where K: Serialize + Debug,

Source

impl Map

pub fn adel<const MAX: usize, K>(&self, key: K)
where K: Serialize + Debug,

Source

impl Map

pub fn bdel<K, B>(&self, key: K, buf: &mut B)
where K: Serialize + Debug, B: Write + AsRef<[u8]>,

Source

impl Map

pub fn get<K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, K>
where K: AsRef<[u8]> + Debug + ?Sized,

Fetch a value from the database into cache, returning a reference-handle asynchronously. The key is referenced directly to perform the query.

Source

impl Map

pub(crate) fn get_cached<K>(&self, key: &K) -> Result<Option<Handle<'_>>>
where K: AsRef<[u8]> + Debug + ?Sized,

Fetch a value from the cache without I/O.

Source

impl Map

pub fn get_blocking<K>(&self, key: &K) -> Result<Handle<'_>>
where K: AsRef<[u8]> + ?Sized,

Fetch a value from the database into cache, returning a reference-handle. The key is referenced directly to perform the query. This is a thread- blocking call.

Source

impl Map

fn get_blocking_opts<K>( &self, key: &K, read_options: &ReadOptions, ) -> Result<Option<DBPinnableSlice<'_>>, Error>
where K: AsRef<[u8]> + ?Sized,

Source

impl Map

pub(crate) fn get_batch<'a, S, K>( self: &'a Arc<Self>, keys: S, ) -> impl Stream<Item = Result<Handle<'_>>> + Send + 'a
where S: Stream<Item = K> + Send + 'a, K: AsRef<[u8]> + Send + Sync + 'a,

Source

impl Map

pub(crate) fn _get_batch_cached<'a, I, K>( &self, keys: I, ) -> impl Iterator<Item = Result<Option<Handle<'_>>>> + Send + use<'_, I, K>
where I: Iterator<Item = &'a K> + ExactSizeIterator + Send, K: AsRef<[u8]> + Send + ?Sized + Sync + 'a,

Source

impl Map

pub(crate) fn get_batch_blocking<'a, I, K>( &self, keys: I, ) -> impl Iterator<Item = Result<Handle<'_>>> + Send + use<'_, I, K>
where I: Iterator<Item = &'a K> + ExactSizeIterator + Send, K: AsRef<[u8]> + Send + ?Sized + Sync + 'a,

Source

impl Map

fn get_batch_blocking_opts<'a, I, K>( &self, keys: I, read_options: &ReadOptions, ) -> impl Iterator<Item = Result<Option<DBPinnableSlice<'_>>, Error>> + Send + use<'_, I, K>
where I: Iterator<Item = &'a K> + ExactSizeIterator + Send, K: AsRef<[u8]> + Send + ?Sized + Sync + 'a,

Source

impl Map

pub fn insert<K, V>(&self, key: &K, val: V)
where K: AsRef<[u8]> + ?Sized, V: AsRef<[u8]>,

Insert Key/Value

  • Key is raw
  • Val is raw
Source

impl Map

pub fn insert_batch<'a, I, K, V>(&'a self, iter: I)
where I: Iterator<Item = (K, V)> + Send + Debug, K: AsRef<[u8]> + Sized + Debug + 'a, V: AsRef<[u8]> + Sized + 'a,

Source

impl Map

pub fn keys<'a, K>( self: &'a Arc<Self>, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send
where K: Deserialize<'a> + Send,

Source

impl Map

pub fn raw_keys(self: &Arc<Self>) -> impl Stream<Item = Result<Key<'_>>> + Send

Source

impl Map

pub fn keys_from<'a, K, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send,

Source

impl Map

pub fn keys_from_raw<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Source

impl Map

pub fn keys_raw_from<'a, K, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: AsRef<[u8]> + ?Sized + Debug + Sync, K: Deserialize<'a> + Send,

Source

impl Map

pub fn raw_keys_from<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: AsRef<[u8]> + ?Sized + Debug,

Source

impl Map

pub fn keys_prefix<'a, K, P>( self: &'a Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send,

Source

impl Map

pub fn keys_prefix_raw<P>( self: &Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Source

impl Map

pub fn keys_raw_prefix<'a, K, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a, K: Deserialize<'a> + Send + 'a,

Source

impl Map

pub fn raw_keys_prefix<'a, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Source

impl Map

pub fn put<K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: Serialize,

Insert Key/Value

  • Key is serialized
  • Val is serialized
Source

impl Map

pub fn put_raw<K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: AsRef<[u8]>,

Insert Key/Value

  • Key is serialized
  • Val is raw
Source

impl Map

pub fn raw_put<K, V>(&self, key: K, val: V)
where K: AsRef<[u8]>, V: Serialize,

Insert Key/Value

  • Key is raw
  • Val is serialized
Source

impl Map

pub fn put_aput<const VMAX: usize, K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: Serialize,

Insert Key/Value

  • Key is serialized
  • Val is serialized to stack-buffer
Source

impl Map

pub fn aput_put<const KMAX: usize, K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: Serialize,

Insert Key/Value

  • Key is serialized to stack-buffer
  • Val is serialized
Source

impl Map

pub fn aput<const KMAX: usize, const VMAX: usize, K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: Serialize,

Insert Key/Value

  • Key is serialized to stack-buffer
  • Val is serialized to stack-buffer
Source

impl Map

pub fn aput_raw<const KMAX: usize, K, V>(&self, key: K, val: V)
where K: Serialize + Debug, V: AsRef<[u8]>,

Insert Key/Value

  • Key is serialized to stack-buffer
  • Val is raw
Source

impl Map

pub fn raw_aput<const VMAX: usize, K, V>(&self, key: K, val: V)
where K: AsRef<[u8]>, V: Serialize,

Insert Key/Value

  • Key is raw
  • Val is serialized to stack-buffer
Source

impl Map

pub fn bput<K, V, Bk, Bv>(&self, key: K, val: V, buf: (Bk, Bv))
where K: Serialize + Debug, V: Serialize, Bk: Write + AsRef<[u8]>, Bv: Write + AsRef<[u8]>,

Insert Key/Value

  • Key is serialized to supplied buffer
  • Val is serialized to supplied buffer
Source

impl Map

pub fn bput_raw<K, V, Bk>(&self, key: K, val: V, buf: Bk)
where K: Serialize + Debug, V: AsRef<[u8]>, Bk: Write + AsRef<[u8]>,

Insert Key/Value

  • Key is serialized to supplied buffer
  • Val is raw
Source

impl Map

pub fn raw_bput<K, V, Bv>(&self, key: K, val: V, buf: Bv)
where K: AsRef<[u8]>, V: Serialize, Bv: Write + AsRef<[u8]>,

Insert Key/Value

  • Key is raw
  • Val is serialized to supplied buffer
Source

impl Map

pub fn qry<K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, K>
where K: Serialize + ?Sized + Debug,

Fetch a value from the database into cache, returning a reference-handle asynchronously. The key is serialized into an allocated buffer to perform the query.

Source

impl Map

pub fn aqry<const MAX: usize, K>( self: &Arc<Self>, key: &K, ) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, MAX, K>
where K: Serialize + ?Sized + Debug,

Fetch a value from the database into cache, returning a reference-handle asynchronously. The key is serialized into a fixed-sized buffer to perform the query. The maximum size is supplied as const generic parameter.

Source

impl Map

pub fn bqry<K, B>( self: &Arc<Self>, key: &K, buf: &mut B, ) -> impl Future<Output = Result<Handle<'_>>> + Send + use<'_, K, B>
where K: Serialize + ?Sized + Debug, B: Write + AsRef<[u8]>,

Fetch a value from the database into cache, returning a reference-handle asynchronously. The key is serialized into a user-supplied Writer.

Source

impl Map

pub(crate) fn qry_batch<'a, S, K>( self: &'a Arc<Self>, keys: S, ) -> impl Stream<Item = Result<Handle<'_>>> + Send + 'a
where S: Stream<Item = K> + Send + 'a, K: Serialize + Debug + 'a,

Source

impl Map

pub fn remove<K>(&self, key: &K)
where K: AsRef<[u8]> + ?Sized + Debug,

Source

impl Map

pub fn rev_keys<'a, K>( self: &'a Arc<Self>, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send
where K: Deserialize<'a> + Send,

Source

impl Map

pub fn rev_raw_keys( self: &Arc<Self>, ) -> impl Stream<Item = Result<Key<'_>>> + Send

Source

impl Map

pub fn rev_keys_from<'a, K, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send,

Source

impl Map

pub fn rev_keys_from_raw<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Source

impl Map

pub fn rev_keys_raw_from<'a, K, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: AsRef<[u8]> + ?Sized + Debug + Sync, K: Deserialize<'a> + Send,

Source

impl Map

pub fn rev_raw_keys_from<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: AsRef<[u8]> + ?Sized + Debug,

Source

impl Map

pub fn rev_keys_prefix<'a, K, P>( self: &'a Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + use<'a, K, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send,

Source

impl Map

pub fn rev_keys_prefix_raw<P>( self: &Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Source

impl Map

pub fn rev_keys_raw_prefix<'a, K, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<Key<'_, K>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a, K: Deserialize<'a> + Send + 'a,

Source

impl Map

pub fn rev_raw_keys_prefix<'a, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<Key<'_>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Source

impl Map

pub fn rev_stream<'a, K, V>( self: &'a Arc<Self>, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send
where K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map from the end.

  • Result is deserialized
Source

impl Map

pub fn rev_raw_stream( self: &Arc<Self>, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send

Iterate key-value entries in the map from the end.

  • Result is raw
Source

impl Map

pub fn rev_stream_from<'a, K, V, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map starting from upper-bound.

  • Query is serialized
  • Result is deserialized
Source

impl Map

pub fn rev_stream_from_raw<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Iterate key-value entries in the map starting from upper-bound.

  • Query is serialized
  • Result is raw
Source

impl Map

pub fn rev_stream_raw_from<'a, K, V, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: AsRef<[u8]> + ?Sized + Debug + Sync, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map starting from upper-bound.

  • Query is raw
  • Result is deserialized
Source

impl Map

pub fn rev_raw_stream_from<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: AsRef<[u8]> + ?Sized + Debug,

Iterate key-value entries in the map starting from upper-bound.

  • Query is raw
  • Result is raw
Source

impl Map

pub fn rev_stream_prefix<'a, K, V, P>( self: &'a Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is serialized
  • Result is deserialized
Source

impl Map

pub fn rev_stream_prefix_raw<P>( self: &Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is serialized
  • Result is raw
Source

impl Map

pub fn rev_stream_raw_prefix<'a, K, V, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a, K: Deserialize<'a> + Send + 'a, V: Deserialize<'a> + Send + 'a,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is raw
  • Result is deserialized
Source

impl Map

pub fn rev_raw_stream_prefix<'a, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is raw
  • Result is raw
Source

impl Map

pub fn stream<'a, K, V>( self: &'a Arc<Self>, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send
where K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map from the beginning.

  • Result is deserialized
Source

impl Map

pub fn raw_stream( self: &Arc<Self>, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send

Iterate key-value entries in the map from the beginning.

  • Result is raw
Source

impl Map

pub fn stream_from<'a, K, V, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map starting from lower-bound.

  • Query is serialized
  • Result is deserialized
Source

impl Map

pub fn stream_from_raw<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Iterate key-value entries in the map starting from lower-bound.

  • Query is serialized
  • Result is raw
Source

impl Map

pub fn stream_raw_from<'a, K, V, P>( self: &'a Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: AsRef<[u8]> + ?Sized + Debug + Sync, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map starting from lower-bound.

  • Query is raw
  • Result is deserialized
Source

impl Map

pub fn raw_stream_from<P>( self: &Arc<Self>, from: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: AsRef<[u8]> + ?Sized + Debug,

Iterate key-value entries in the map starting from lower-bound.

  • Query is raw
  • Result is raw
Source

impl Map

pub fn stream_prefix<'a, K, V, P>( self: &'a Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + use<'a, K, V, P>
where P: Serialize + ?Sized + Debug, K: Deserialize<'a> + Send, V: Deserialize<'a> + Send,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is serialized
  • Result is deserialized
Source

impl Map

pub fn stream_prefix_raw<P>( self: &Arc<Self>, prefix: &P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + use<'_, P>
where P: Serialize + ?Sized + Debug,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is serialized
  • Result is raw
Source

impl Map

pub fn stream_raw_prefix<'a, K, V, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<KeyVal<'_, K, V>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a, K: Deserialize<'a> + Send + 'a, V: Deserialize<'a> + Send + 'a,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is raw
  • Result is deserialized
Source

impl Map

pub fn raw_stream_prefix<'a, P>( self: &'a Arc<Self>, prefix: &'a P, ) -> impl Stream<Item = Result<KeyVal<'_>>> + Send + 'a
where P: AsRef<[u8]> + ?Sized + Debug + Sync + 'a,

Iterate key-value entries in the map where the key matches a prefix.

  • Query is raw
  • Result is raw
Source

impl Map

pub fn watch_prefix<K>(&self, prefix: K) -> impl Future<Output = ()> + Send + '_
where K: Serialize,

Source

impl Map

pub fn watch_raw_prefix<'a, K>( &self, prefix: &'a K, ) -> impl Future<Output = ()> + Send + use<K>
where K: AsRef<[u8]> + ?Sized + 'a,

Source

impl Map

pub(crate) fn notify<K>(&self, key: &K)
where K: AsRef<[u8]> + Ord + ?Sized,

Source

impl Map

pub(crate) fn open( engine: &Arc<Engine>, name: &'static str, ) -> Result<Arc<Self>>

pub fn property_integer(&self, name: &CStr) -> Result<u64>

pub fn property(&self, name: &str) -> Result<String>

pub fn name(&self) -> &str

pub(crate) fn engine(&self) -> &Arc<Engine>

pub(crate) fn cf(&self) -> impl AsColumnFamilyRef + '_