fn compute_workers(
devices: &MultiDevice,
config: &Config,
default_worker_count: Option<usize>,
topology_len: usize,
chan_limit: usize,
) -> Vec<usize>Expand description
Determine the worker groupings. Each indice represents a hardware queue and contains the number of workers which will service it. The vector is truncated to the number of cores on systems with multiple hardware queues per core, and the per-pool count is capped well below NVMe capacity.