pub(crate) type BatchQuery<'a> = SmallVec<[KeyBuf; 1]>;Expand description
Stores the owned keys in a batched point query.
Small batches remain inline up to the crate’s configured batch budget. Larger batches spill to the heap without changing query order.
Aliased Type
pub(crate) struct BatchQuery<'a> { /* private fields */ }